from note.messenger.email.mail import Mail
from note.messenger.line.line import Line
from note.messenger.telegram.telegram import Telegram

class NOTE:

    def __init__(self):
        print('initialize')

    def Mail(self, API_ID, API_PASSWORD):
        print("EMAIL Selected")
        return Mail(API_ID, API_PASSWORD)

    def Line(self, API_ID, API_PASSWORD):
        print("Send Message through LINE")
        return Line(API_ID, API_PASSWORD)

    def Telegram(self, API_ID, API_PASSWORD):
        print("Send Message through Telegram")
        return Telegram(API_ID, API_PASSWORD)



class messenger:
    def __init__(self, API_ID, API_PASSWORD):
        self.API_ID = API_ID
        self.API_PASSWORD = API_PASSWORD
        self._msg = ""

    @property
    def recevier(self):
        return self._recevier

    @property
    def message(self):
        return self._msg

    @recevier.setter
    def recevier(self, recv_addr):
        self._recevier = recv_addr
    
    @message.setter
    def message(self, text):
        self._msg = text